@@ -359,7 +359,7 @@ def publication_venue_to_html(entry, config):
     )
 
     if any(special_publication_info):
-        publication_method = ", ".join(special_publication_info)
+        publication_method = ", ".join([i for i in special_publication_info if i])
         assert publication_method
         publication_method = (
             f'<span class="publicationmethod">{publication_method}</span>'
